==> lms-1.8.0rc5.tar.gz: lms/lib/locale/pl/fortunes.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: fortunes.php,v 1.4.2.1 2005/12/07 08:56:19 alec Exp $
 */

$fortunes[] = "Możesz się pokaleczyć wymachując siekierą?";
$fortunes[] = "Komputer nie podłączony do źródła zasilania zdecydowanie odmówi działania.";
$fortunes[] = "Doświadczenie to coś, co zdobywasz tuż po chwili w której go potrzebowałeś.";
$fortunes[] = "Najlepszą metodą do zainspirowania odkrywczych myśli, jest zaklejenie koperty.";
$fortunes[] = "Wszystko zabiera znacznie więcej czasu, niż by się wydawało.";
$fortunes[] = "Zawsze kiedy masz właśnie coś zrobić, okazuje się, że najpierw musisz zrobić coś innego.";
$fortunes[] = "Każde rozwiązanie rodzi nowe problemy.";
$fortunes[] = "Głupcy są tak pomysłowi, że niemożliwe jest stworzenie czegoś, z czym każdy głupi sobie poradzi.";
$fortunes[] = "Matka Natura jest suką.";
$fortunes[] = "Rzeczy ulegają zniszczeniu, wprost proporcjonalnie do swej wartości.";
$fortunes[] = "Wszystkie sprawy szlag trafia jednocześnie.";
$fortunes[] = "Jeżeli wydaje ci się, że już gorzej być nie może - na pewno będzie.";
$fortunes[] = "Zawsze, kiedy wydaje ci się, że będzie dobrze - kompletnie się mylisz.";
$fortunes[] = "Zawsze, kiedy wydaje ci się, że będzie źle też się mylisz - będzie jeszcze gorzej.";
$fortunes[] = "Bardzo dużo można zauważyć, gdy się patrzy.";
$fortunes[] = "Jeśli coś się wydarza to znaczy, że jest to możliwe. Zatem w walce między tobą, a światem, stań po stronie świata.";
$fortunes[] = "W poszukiwaniu rozwiązania problemu, najbardziej pomocna jest znajomość odpowiedzi.";
$fortunes[] = "Każdy przedmiot niezależnie od położenia, może w dowolnej chwili zadziałać w zupełnie nieoczekiwany sposób z przyczyn, które są albo całkowicie niejasne, albo zupełnie tajemnicze.";
$fortunes[] = "Wymiary będą zawsze podane w najmniej użytecznych jednostkach.";
$fortunes[] = "Każdy przewód przycięty na długość, okaże się za krótki.";
$fortunes[] = "Stopień głupoty twojego postępowania, jest wprost proporcjonalny do liczby przyglądających ci się osób.";
$fortunes[] = "Prawdopodobieństwo wyczerpania się baterii, jest wprost-proporcjonalne do zapotrzebowania na kalkulator.";
$fortunes[] = "Ciężar upuszczonej części jest wprost proporcjonalny do ceny obszaru uderzonego.";
$fortunes[] = "To czego szukasz, znajdziesz w ostatnim spośród możliwych miejsc.";
$fortunes[] = "Wniosek to punkt, w którym nie masz już siły dalej myśleć.";
$fortunes[] = "To co może się nie udać, nie uda się na pewno.";
$fortunes[] = "Cztery zjawiska blokują postęp ludzkości - ignorancja, głupota, komitety normalizacyjne, oraz ludzie sprzedający komputery.";
$fortunes[] = "Istnieją trzy rodzaje kłamstw - kłamstwa odruchowe, powszechne oraz testy komputerowe.";
$fortunes[] = "Człowiek pracujący z komputerem, nie postępuje zgodnie z wymaganiami komputera.";
$fortunes[] = "Systemy odporne na idiotów, obsługiwane są właśnie przez nich.";
$fortunes[] = "Rozłożenie dowolnego urządzenia na części jest proste, ponowne jego złożenie, tak żeby działało, jest niemożliwe.";
$fortunes[] = "Każdy skomplikowany montaż wymaga trzech rąk.";
$fortunes[] = "Każdy prosty montaż wymaga czterech rąk.";
$fortunes[] = "Sprawy pozostawione same sobie, zmieniają się ze złych na jeszcze gorsze.";
$fortunes[] = "Wszystkie komputery PC są kompatybilne, ale niektóre są kompatybilniejsze od innych. Twój jest zawsze mniej kompatybilny.";
$fortunes[] = "Pustą dyskietkę możesz przeszukiwać długo i bezskutecznie. Długo i bezskutecznie możesz przeszukiwać także pełną dyskietkę. Wniosek - każdą dyskietkę możesz przeszukiwać długo i bezskutecznie.";
$fortunes[] = "Komputer służy do tego aby ułatwić ci pracę, której bez niego w ogóle byś nie miał.";
$fortunes[] = "Dla komputera nie ma rzeczy niemożliwych z wyjątkiem tych, których od niego wymagamy.";
$fortunes[] = "W świecie komputerów żadna awaria się nie kończy, ponieważ przechodzi zawsze w następną.";
$fortunes[] = "Awaria komputera wyczekuje cierpliwie na najbardziej niedogodny moment, aby bezlitośnie zaatakować.";
$fortunes[] = "W pracy z komputerem, opieranie się na jakichkolwiek zasadach jest błędem.";
$fortunes[] = "Drobne awarie nie isnieją, jeżeli miała jednak miejsce drobna awaria, oznacza to, że nie poznałeś jeszcze jej rzeczywistych rozmiarów.";
$fortunes[] = "Im doskonalej program wykonuje swoje funkcje, tym dotkliwiej cię zawiedzie. Każdy inny program zawodzi tak samo dotkliwie. Tylko niepotrzebny nikomu program, działa bez zakłóceń.";
$fortunes[] = "Masz zawsze o jeden wirus więcej niż sądzisz.";
$fortunes[] = "Program kalkulacyjny, który daje właściwy i przyjazny wynik - kłamie.";
$fortunes[] = "Wyjątki są liczniejsze od reguł. Od wszystkich uznanych wyjątków istnieją wyjątki.";
$fortunes[] = "Klientowi nigdy nie przyjdzie na myśl ile kosztuje projekt, tylko ile można na tym projekcie zaoszczędzić. Jeżeli udało ci się wprowadzić w programie wymagane przez klienta poprawki, wtedy on z nich zrezygnuje. Żaden klient nie wie czego właściwie chce. Każdy klient wie dokładnie czego nie chce. Żaden klient nie chce tego co masz już gotowe. Nie wie także co chciałby mieć zamiast tego. Klient, który najmniej płaci, marudzi najwięcej. Klient żąda największych zmian dokładnie wtedy, kiedy produkt jest już gotowy.";
$fortunes[] = "Na polecenie \"napisz tak lub nie\" użytkownik wpisuje \"tak lub nie\". Na polecenie \"wciśnij Enter\" użytkownik wpisuje \"Enter\". Na polecenie \"naciśnij dowolny klawisz\", użytkownik naciska na klawisz \"reset\". Wniosek: Nie ma programów całkowicie idiotoodpornych.";
$fortunes[] = "W zespole programistów każdy ma genialny plan rozwiązania problemu. Wszystkie plany się wzajemnie wykluczają i żaden nie prowadzi do poprawnego rozwiązania. Liczba osób w zespole programistycznym ma tendencje wzrastające, niezależnie od ilości pracy.";
$fortunes[] = "01:04 < [hunter]> robić dokumentacje ?
01:04 < [hunter]> :)
01:04 <@Warden> dokumentację? rób
01:04 <@Warden> ;)
01:04 <@Warden> Baseciq:: jest chętny!
01:04 <@Warden> ;)
01:05 <@Baseciq> zwiążcie go!!!!!!!!!
01:05 <@Baseciq> szybko!!!
01:05 <@Baseciq> bo ucieknie!!!
01:06 <@agaran> :>
01:08 <@agaran> :>>> Hunterq uwazaj";

$fortunes[] = "19:16.31| <@Baseciq> SELECT users.id, lastname, SUM((type * -2 + 7) * value) FROM users LEFT OUTER JOIN cash ON users.id = cash.userid AND (cash.type = 3 OR cash.type = 4) WHERE status=3 AND deleted=0 GROUP BY users.id;
19:17.00| <@Lexx__> Wy z tymi zapytaniami jobla dostajcie ;P";		     

$fortunes[] = "Lexx (0:16)
GPL nie przewiduje zdaje sie braku odpowiedzialnosci za smierc przez kod ;]";

$fortunes[] = "Subject: [lms] Re: Sieci

Witam.
[hunter napisał:]
> e, to nie Ty miałeś z arpami coś nie tak jakoś tak ze 3 krzynki i pół
> winiacza temu?

Tak, ustawiałem arp 00:00:00:00:00:00 dla adresów broadcastowych i
padał mi wins ;-)
--
Łukasz Jarosław Mozer ;]";

$fortunes[] = "Ilu potrzeba developerów LMSa do wkręcenia żarówki?
Żadnego. Developerzy LMSa zrobią odrazu nową lampę.";

$fortunes[] = "Prima Aprilis 2004 - lms@lists.rulez.pl:
<@Baseciq>     LMS-Linux 2.0 - dostępny na ftp...
<@Woyteck>     Dlaczego ISO ma 33 bajty?
<@Detekt>      Ponieważ baset wynalazł nowy algorytm optymalizacji.
<@T.Chiliński> A ja myślę, że to wersja demo, pozbawiona pełnej funkcjonalności.";

$fortunes[] = "Subject: [lms] Re: przycisk rozlicz ;-)

powiem   tak.. u mnie w firmie jest CallCenter z historia rozmow z
klientem...
jedna z lepszych adnotacji z dzialu DH:
 \"Klient ma problem egzystencjonalny, prawdopodobnie pomylil dzien z
 noca, albo butelke wody mineralnej z inna woda przezroczysta
 
 ... nie potrafil wypelnic formularza rejestracji domeny\"

Pozdrawiam,
Tomasz T. Ciaszczyk";

$fortunes[] = "Subject: [lms] Re: przycisk rozlicz ;-)

powiem   tak.. u mnie w firmie jest CallCenter z historia rozmow z
klientem...

DH: przekierowanie do BOK
BOK: klientka jest glupia bo sie pyta czy prawym czy lewym pzyciskiem
myszki kliknac na 'dalej'
5 minut pozniej nowa rozmowa od tej samej klientki:
BOK: nie chce z nim gadac
DT: \"przemila rozmowa o tym jak skanowac dokumenty, wysylac je mailem,
ewentualnie przeskalowac aby Pani modem sie nie znudzil wysylajac
maila 5 godzin. Przy okazji mam nocleg w Poznaniu\" dlugosc rozmowy 68 minut

Pozdrawiam,
Tomasz T. Ciaszczyk";

mt_srand ((double) microtime()* 100000000);
$layout[fortune] = $fortunes[mt_rand(0,sizeof($fortunes)-1)];

?>

==> lms-1.10.2.tar.gz: lms/lib/locale/pl/fortunes.php <==
<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: fortunes.php,v 1.8.2.1 2007/08/17 13:15:14 alec Exp $
 */

$fortunes[] = "Możesz się pokaleczyć wymachując siekierą?";
$fortunes[] = "Komputer nie podłączony do źródła zasilania zdecydowanie odmówi działania.";
$fortunes[] = "Doświadczenie to coś, co zdobywasz tuż po chwili w której go potrzebowałeś.";
$fortunes[] = "Najlepszą metodą do zainspirowania odkrywczych myśli, jest zaklejenie koperty.";
$fortunes[] = "Wszystko zabiera znacznie więcej czasu, niż by się wydawało.";
$fortunes[] = "Zawsze kiedy masz właśnie coś zrobić, okazuje się, że najpierw musisz zrobić coś innego.";
$fortunes[] = "Każde rozwiązanie rodzi nowe problemy.";
$fortunes[] = "Głupcy są tak pomysłowi, że niemożliwe jest stworzenie czegoś, z czym każdy głupi sobie poradzi.";
$fortunes[] = "Matka Natura jest suką.";
$fortunes[] = "Rzeczy ulegają zniszczeniu, wprost proporcjonalnie do swej wartości.";
$fortunes[] = "Wszystkie sprawy szlag trafia jednocześnie.";
$fortunes[] = "Jeżeli wydaje ci się, że już gorzej być nie może - na pewno będzie.";
$fortunes[] = "Zawsze, kiedy wydaje ci się, że będzie dobrze - kompletnie się mylisz.";
$fortunes[] = "Zawsze, kiedy wydaje ci się, że będzie źle też się mylisz - będzie jeszcze gorzej.";
$fortunes[] = "Bardzo dużo można zauważyć, gdy się patrzy.";
$fortunes[] = "Jeśli coś się wydarza to znaczy, że jest to możliwe. Zatem w walce między tobą, a światem, stań po stronie świata.";
$fortunes[] = "W poszukiwaniu rozwiązania problemu, najbardziej pomocna jest znajomość odpowiedzi.";
$fortunes[] = "Każdy przedmiot niezależnie od położenia, może w dowolnej chwili zadziałać w zupełnie nieoczekiwany sposób z przyczyn, które są albo całkowicie niejasne, albo zupełnie tajemnicze.";
$fortunes[] = "Wymiary będą zawsze podane w najmniej użytecznych jednostkach.";
$fortunes[] = "Każdy przewód przycięty na długość, okaże się za krótki.";
$fortunes[] = "Stopień głupoty twojego postępowania, jest wprost proporcjonalny do liczby przyglądających ci się osób.";
$fortunes[] = "Prawdopodobieństwo wyczerpania się baterii, jest wprost-proporcjonalne do zapotrzebowania na kalkulator.";
$fortunes[] = "Ciężar upuszczonej części jest wprost proporcjonalny do ceny obszaru uderzonego.";
$fortunes[] = "To czego szukasz, znajdziesz w ostatnim spośród możliwych miejsc.";
$fortunes[] = "Wniosek to punkt, w którym nie masz już siły dalej myśleć.";
$fortunes[] = "To co może się nie udać, nie uda się na pewno.";
$fortunes[] = "Cztery zjawiska blokują postęp ludzkości - ignorancja, głupota, komitety normalizacyjne, oraz ludzie sprzedający komputery.";
$fortunes[] = "Istnieją trzy rodzaje kłamstw - kłamstwa odruchowe, powszechne oraz testy komputerowe.";
$fortunes[] = "Człowiek pracujący z komputerem, nie postępuje zgodnie z wymaganiami komputera.";
$fortunes[] = "Systemy odporne na idiotów, obsługiwane są właśnie przez nich.";
$fortunes[] = "Rozłożenie dowolnego urządzenia na części jest proste, ponowne jego złożenie, tak żeby działało, jest niemożliwe.";
$fortunes[] = "Każdy skomplikowany montaż wymaga trzech rąk.";
$fortunes[] = "Każdy prosty montaż wymaga czterech rąk.";
$fortunes[] = "Sprawy pozostawione same sobie, zmieniają się ze złych na jeszcze gorsze.";
$fortunes[] = "Wszystkie komputery PC są kompatybilne, ale niektóre są kompatybilniejsze od innych. Twój jest zawsze mniej kompatybilny.";
$fortunes[] = "Pustą dyskietkę możesz przeszukiwać długo i bezskutecznie. Długo i bezskutecznie możesz przeszukiwać także pełną dyskietkę. Wniosek - każdą dyskietkę możesz przeszukiwać długo i bezskutecznie.";
$fortunes[] = "Komputer służy do tego aby ułatwić ci pracę, której bez niego w ogóle byś nie miał.";
$fortunes[] = "Dla komputera nie ma rzeczy niemożliwych z wyjątkiem tych, których od niego wymagamy.";
$fortunes[] = "W świecie komputerów żadna awaria się nie kończy, ponieważ przechodzi zawsze w następną.";
$fortunes[] = "Awaria komputera wyczekuje cierpliwie na najbardziej niedogodny moment, aby bezlitośnie zaatakować.";
$fortunes[] = "W pracy z komputerem, opieranie się na jakichkolwiek zasadach jest błędem.";
$fortunes[] = "Drobne awarie nie isnieją, jeżeli miała jednak miejsce drobna awaria, oznacza to, że nie poznałeś jeszcze jej rzeczywistych rozmiarów.";
$fortunes[] = "Im doskonalej program wykonuje swoje funkcje, tym dotkliwiej cię zawiedzie. Każdy inny program zawodzi tak samo dotkliwie. Tylko niepotrzebny nikomu program, działa bez zakłóceń.";
$fortunes[] = "Masz zawsze o jeden wirus więcej niż sądzisz.";
$fortunes[] = "Program kalkulacyjny, który daje właściwy i przyjazny wynik - kłamie.";
$fortunes[] = "Wyjątki są liczniejsze od reguł. Od wszystkich uznanych wyjątków istnieją wyjątki.";
$fortunes[] = "Klientowi nigdy nie przyjdzie na myśl ile kosztuje projekt, tylko ile można na tym projekcie zaoszczędzić. Jeżeli udało ci się wprowadzić w programie wymagane przez klienta poprawki, wtedy on z nich zrezygnuje. Żaden klient nie wie czego właściwie chce. Każdy klient wie dokładnie czego nie chce. Żaden klient nie chce tego co masz już gotowe. Nie wie także co chciałby mieć zamiast tego. Klient, który najmniej płaci, marudzi najwięcej. Klient żąda największych zmian dokładnie wtedy, kiedy produkt jest już gotowy.";
$fortunes[] = "Na polecenie \"napisz tak lub nie\" użytkownik wpisuje \"tak lub nie\". Na polecenie \"wciśnij Enter\" użytkownik wpisuje \"Enter\". Na polecenie \"naciśnij dowolny klawisz\", użytkownik naciska na klawisz \"reset\". Wniosek: Nie ma programów całkowicie idiotoodpornych.";
$fortunes[] = "W zespole programistów każdy ma genialny plan rozwiązania problemu. Wszystkie plany się wzajemnie wykluczają i żaden nie prowadzi do poprawnego rozwiązania. Liczba osób w zespole programistycznym ma tendencje wzrastające, niezależnie od ilości pracy.";
$fortunes[] = "01:04 < [hunter]> robić dokumentacje ?
01:04 < [hunter]> :)
01:04 <@Warden> dokumentację? rób
01:04 <@Warden> ;)
01:04 <@Warden> Baseciq:: jest chętny!
01:04 <@Warden> ;)
01:05 <@Baseciq> zwiążcie go!!!!!!!!!
01:05 <@Baseciq> szybko!!!
01:05 <@Baseciq> bo ucieknie!!!
01:06 <@agaran> :>
01:08 <@agaran> :>>> Hunterq uwazaj";

$fortunes[] = "19:16.31| <@Baseciq> SELECT users.id, lastname, SUM((type * -2 + 7) * value) FROM users LEFT OUTER JOIN cash ON users.id = cash.userid AND (cash.type = 3 OR cash.type = 4) WHERE status=3 AND deleted=0 GROUP BY users.id;
19:17.00| <@Lexx__> Wy z tymi zapytaniami jobla dostajcie ;P";		     

$fortunes[] = "Lexx (0:16)
GPL nie przewiduje zdaje sie braku odpowiedzialnosci za smierc przez kod ;]";

$fortunes[] = "Subject: [lms] Re: Sieci

Witam.
[hunter napisał:]
> e, to nie Ty miałeś z arpami coś nie tak jakoś tak ze 3 krzynki i pół
> winiacza temu?

Tak, ustawiałem arp 00:00:00:00:00:00 dla adresów broadcastowych i
padał mi wins ;-)
--
Łukasz Jarosław Mozer ;]";

$fortunes[] = "Ilu potrzeba developerów LMSa do wkręcenia żarówki?
Żadnego. Developerzy LMSa zrobią odrazu nową lampę.";

$fortunes[] = "Prima Aprilis 2004 - lms@lists.lms.org.pl:
<@Baseciq>     LMS-Linux 2.0 - dostępny na ftp...
<@Woyteck>     Dlaczego ISO ma 33 bajty?
<@Detekt>      Ponieważ baset wynalazł nowy algorytm optymalizacji.
<@T.Chiliński> A ja myślę, że to wersja demo, pozbawiona pełnej funkcjonalności.";

$fortunes[] = "Subject: [lms] Re: przycisk rozlicz ;-)

powiem   tak.. u mnie w firmie jest CallCenter z historia rozmow z
klientem...
jedna z lepszych adnotacji z dzialu DH:
 \"Klient ma problem egzystencjonalny, prawdopodobnie pomylil dzien z
 noca, albo butelke wody mineralnej z inna woda przezroczysta
 
 ... nie potrafil wypelnic formularza rejestracji domeny\"

Pozdrawiam,
Tomasz T. Ciaszczyk";

$fortunes[] = "Subject: [lms] Re: przycisk rozlicz ;-)

powiem   tak.. u mnie w firmie jest CallCenter z historia rozmow z
klientem...

DH: przekierowanie do BOK
BOK: klientka jest glupia bo sie pyta czy prawym czy lewym pzyciskiem
myszki kliknac na 'dalej'
5 minut pozniej nowa rozmowa od tej samej klientki:
BOK: nie chce z nim gadac
DT: \"przemila rozmowa o tym jak skanowac dokumenty, wysylac je mailem,
ewentualnie przeskalowac aby Pani modem sie nie znudzil wysylajac
maila 5 godzin. Przy okazji mam nocleg w Poznaniu\" dlugosc rozmowy 68 minut

Pozdrawiam,
Tomasz T. Ciaszczyk";

mt_srand ((double) microtime()* 100000000);
$layout[fortune] = $fortunes[mt_rand(0,sizeof($fortunes)-1)];

?>
